#
# spec file for package libevtx
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	libevtx1
Name:           libevtx
Version:        20221101
Release:        4.2
Summary:        Library and tools to access the Windows XML Event Log (EVTX) format
License:        GFDL-1.3-only AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libevtx
Source:         https://github.com/libyal/libevtx/releases/download/%version/libevtx-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libevtx/releases/download/%version/libevtx-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source10:       Windows_XML_Event_Log_EVTX.pdf
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20220115
BuildRequires:  pkgconfig(libcdirectory) >= 20220105
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20220107
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libexe) >= 20210424
BuildRequires:  pkgconfig(libfcache) >= 20220110
BuildRequires:  pkgconfig(libfdata) >= 20211023
BuildRequires:  pkgconfig(libfdatetime) >= 20220112
BuildRequires:  pkgconfig(libfguid) >= 20220113
BuildRequires:  pkgconfig(libfvalue) >= 20220120
BuildRequires:  pkgconfig(libfwevt) >= 20220723
BuildRequires:  pkgconfig(libfwnt) >= 20220922
BuildRequires:  pkgconfig(libregf) >= 20221026
BuildRequires:  pkgconfig(libuna) >= 20220611
BuildRequires:  pkgconfig(libwrc) >= 20220720
BuildRequires:  pkgconfig(python3)
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tools to access the Windows XML Event Log (EVTX) format.
For the Windows pre-XML Event Log (EVT) format, see libevt.

%package -n %lname
Summary:        Library to access the Windows XML Event Log (EVTX) format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
Library to access the Windows Event Log (EVT) format.
For the Windows pre-XML Event Log (EVT) format, see libevt.

%package tools
Summary:        Utilities to export events from Windows XML event files (EVTX)
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Tools for parsing EVTX files. These include evtxinfo and evtxexport.

%package devel
Summary:        Development files for libevtx, a Windows XML Event file parser
License:        GFDL-1.3-only AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libevtx is a library to access the Windows XML Event log format.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libevtx.so.*

%files -n %name-tools
%_bindir/evtx*
%_mandir/man1/evt*.1*

%files -n %name-devel
%doc Windows_XML_Event_Log*.pdf
%_includedir/libevtx.h
%_includedir/libevtx/
%_libdir/libevtx.so
%_libdir/pkgconfig/libevtx.pc
%_mandir/man3/libevtx.3*

%files %python_files
%license COPYING*
%python_sitearch/pyevtx.so

%changelog
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Wed Nov  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221101
  * No changelog was provided
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirements on libcdirectory, libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sun Jul 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220724
  * Added event version functions
* Fri Jan 21 2022 Jan Engelhardt <jengelh@inai.de>
- Edit specfile to do multipython builds.
  (Happens to reenable python2 on Leap 15)
* Thu Nov 25 2021 Jan Engelhardt <jengelh@inai.de>
- Add keyring
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210525
  * No changelog was provided
- Drop python2 module build.
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210504 (c23e14d0)
  * No changelog was provided
- Add system-libs.patch
* Sat Dec 26 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200709
  * worked on python bindings
* Tue May  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Allow distros to disable python2 bindings (bcond_without):
  Tumbleweed already declares this, as python2 is EOL.
* Tue Apr  7 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20191221
  * Added binary XML creation time to API and evtxexport #21
  * worked on tests
- rename python-libevtx to python2-libevtx
- add python3 subpackage
* Thu Mar 28 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181227
  * work on python bindings
  * code clean-up
  * documentation fixes
  * Added fallback for caseless wide string compare
  * address libfdata API changes
* Tue Jan 26 2016 Greg.Freemyer@gmail.com
- update to v0~20160107
  * 2016 update
  * worked on Python 3 support
  * Worked on format support
  * applied updates
  * worked on Python bindings
  * updated m4 scripts
  * changed version for pypi repacking
  * worked on setup.py
- use internal libfwevt.  fixes failures found in integration testing with plaso
* Mon Jan 12 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
- Use libyal packages from OBS where appropriate
  * test the builds by running "run_tests.py" from the plaso tarball
  * don't use OBS packages thst introduce test failures.
* Mon Dec 22 2014 Greg.Freemyer@gmail.com
- update to 0~20141112
  * changes to expose the event identifier qualifiers in the python bindings
  * updated dependencies and corresponding changes
  * update Python-bindings tests
- update URL and Source fields to use the new github site
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to 0~20140901
  * bug fix in Python-bindings
- update Source: field to have fullpath, delete DL_URL
* Thu Aug 28 2014 Greg.Freemyer@gmail.com
- testing failed, passes if these 2 internal packages are used
  * libfguid
  * libfdatetime
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pyevtx = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to 0~20140731
  * bug fix in Python-bindings
  * worked on dpkg debug packages support
  * updated dependencies
  * worked on Python-bindings
  * replaced PackageMaker for pkgbuild
  * code clean up
  * worked on setup.py
  * added evtxexport man page
  * removed examples
  * 2014 update
  * small fix in evtxexport -h output
- use libregf from external package
* Tue Nov 26 2013 Greg.Freemyer@gmail.com
- using internal libregf, latest factory update broke libevtx
* Mon Nov  4 2013 Greg.Freemyer@gmail.com
- update to 0~20131013
  * updated dependencies
- using internal libwrc, latest factory update broke libevtx
- removed 0~ from buildrequires dependencies
* Wed Oct  2 2013 Greg.Freemyer@gmail.com
-  update to 0~20130923
  * updated dependencies
  * worked on libcthreads build support
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to 0~20130727
  * updated dependencies
  * pyevtx
  - changed event identifier to an unsigned long
  - fixes for >2G file objects in BFIO glue code
  - other updates and bug fixes
  * removed unnecessary restriction in library include headers
  * worked on tests
  * improved reading from dirty files with an incorrect number of chunks
  * fix for encoding special characters in XML output
  * added support for parsing ProcessingErrorData
  * worked on improving corruption detection for recovered records
  * textual changes
  * fixed codepage 1255 restriction
  * improvements to message string support
- changed to gz compression to simplyfy donwload/convert
- used factory version of libyal libraries if possible
* Mon Apr  8 2013 Greg.Freemyer@gmail.com
- update to 0~20130329
  * bug fix for recent libfdata changes
* Thu Apr  4 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130319) for build.opensuse.org
